.g-thumbnail-size-input{vertical-align:middle;border:1px solid #ccc;border-radius:3px;width:90px;padding:5px 10px;font-size:12px}.g-thumbnail-size-between{vertical-align:middle;margin:0 9px;font-size:14px}.g-thumbnail-crop-container{margin-left:20px}.g-thumbnail-size-form-container{margin-bottom:15px}.g-thumbnail-custom-target-container{margin-bottom:8px}.g-thumbnail-custom-target-container .g-target-result{background-color:#eee;border-radius:3px;margin-bottom:6px;padding:5px 10px}.g-thumbnail-container{vertical-align:top;margin:0 10px 10px 0;display:inline-block;position:relative}.g-thumbnail-container .g-thumbnail-actions-container{opacity:0;background-color:#fffc;border-radius:3px;padding:2px 4px;font-size:12px;transition:opacity .4s;display:inline-block;position:absolute;top:4px;right:4px}.g-thumbnail-container .g-thumbnail-actions-container.g-show{opacity:1}.g-thumbnail-container .g-thumbnail-actions-container a{color:#333}.g-thumbnails-header-container{margin-bottom:8px}
/*$vite$:1*/